#
# spec file for package obex-data-server
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           obex-data-server
Version:        0.4.6
Release:        16.5
Summary:        Obex DBus API
License:        GPL-2.0-or-later
Group:          Hardware/Mobile
URL:            http://wiki.muiline.com/obex-data-server
Source:         http://tadas.dailyda.com/software/%{name}-%{version}.tar.gz
Patch0:         obex-data-server-openobex_EnumerateInterfaces.patch
BuildRequires:  bluez-devel
BuildRequires:  dbus-1-glib-devel
BuildRequires:  gtk2-devel
BuildRequires:  libusb-devel
BuildRequires:  openobex-devel

%description
Obex-Data-Server provides a obex dbus api. Used for bluetooth
applications to transfer and receive data.

%prep
%autosetup -p0

%build
CFLAGS="%{optflags} -fno-strict-aliasing" %configure --with-dbus-dir=%{_datadir}/dbus-1
%make_build

%install
%make_install

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%license COPYING
%doc AUTHORS INSTALL ChangeLog dbus-api.txt NEWS
%{_bindir}/obex-data-server
%dir %{_sysconfdir}/obex-data-server
%config %{_sysconfdir}/obex-data-server/*.xml
%{_mandir}/*/*
%{_datadir}/dbus-1/services/obex-data-server.service

%changelog
* Wed Feb 21 2024 Michael Vetter <mvetter@suse.com>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
- Clean spec file
* Tue Nov 19 2013 ro@suse.de
- obex-data-server-openobex_EnumerateInterfaces.patch:
  openobex removed OBEX_FindInterfaces(), adapt code
* Mon Apr 15 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Fri Jun 17 2011 vuntz@opensuse.org
- Update to version 0.4.6:
  + Fix --disable-usb build flag
  + Properly handle empty and invalid type headers in server GET
    and PUT
  + Fix crasher during SDP discovery
  + Fix BIP server PUT
  + Disable directory creation when writing is not allowed
  + Improve logging system (prefixes indicating which session a
    particular message belongs to)
* Sat Mar 27 2010 vuntz@opensuse.org
- Update to version 0.4.5:
  + Add support for GET folder listing with name header in server
    (usually name header is not used!)
  + Fix system bus configuration file according to new default
    policy
  + Use locales only for filenames (previously caused D-Bus
    disconnect when translated errors were passed)
  + Refine logging functionality (ability to log to syslog,
    enable/disable debug messages)
  + Use silent and non-recursive makefiles
  + New OPP test script: ods-opp-test.py
  + Request timeout system (when no response is received from
    remote device in 15 seconds after request was issued, TimeOut
    error will happen and connection will be closed)
  + Transfer suspension timeout system (when auto_accept is False
    for server and Accept() or Reject() is not called in 15 seconds
    after TransferStarted signal, incoming file will be
    automatically rejected)
  + Support for TTY transport (server and client). TTY server can
    be used in USB gadgets, session support is somewhat
    experimental and only for testing purposes
  + A bunch of other bugs fixed and code cleaned up in quiet a few
    places :)
- Changes from version 0.4.4:
  + Revert openobex 1.4 dependency. Now ods builds with openobex
    1.3 even with usb support on
- Changes from version 0.4.3:
  + Fix Nokia SDP workaround (this has been broken back in 0.4)
  + Actually export RemoteCopy and RemoteMove methods
  + Export more information about USB interfaces. ods now depends
    on libusb and openobex 1.4 for usb support. USB support can be
    disable with --disable-usb.
  + Export OBEXCommand in TransferInfo to differentiate between PUT
    and GET requests
  + Various server fixes
- Drop obex-data-server-transferstarted.patch: fixed upstream.
- Drop obex-data-server-unbreak-file-uris.patch: this should not be
  needed, and apps should be fixed to not pass URI but path.
- Add libusb-devel BuildRequires, and gtk2-devel BuildRequires for
  BIP support.
- Remove AutoReqProv: it's default now.
- Do not define a custom prefix.
- Use makeinstall macro.
* Thu Oct  8 2009 vuntz@opensuse.org
- Add obex-data-server-transferstarted.patch taken from upstream to
  fix the emission of the TransferStarted signal. Make notification
  of received files in gnome-user-share visible. Fix bnc#515025.
* Thu Mar 26 2009 crrodriguez@suse.de
- fix BuildRequires
* Sat Jan 17 2009 tpatzig@suse.de
- Update to 0.4.2
  * Implement RemoteCopy and RemoteMove methods in Session
  * add more errors corresponding to OBEX responses
  * fix for ARM build
* Sun Oct 26 2008 jpr@novell.com
- Update to 0.4.1, most importantly for bluez 4.x support
  * Fix a race condition when client app misses
    ServerSession.TransferStarted signal
  * Do not use g_assert for checking if DBus context is set in
    Session and ServerSession methods
  * Fix TransferStarted signal emission in ServerSession
  * Implement partial BIP profile support (ImagePush and
    RemoteDisplay features supported)
  * Add support for Bluez 4.x (still compatible with Bluez 3.x)
  * Add support for USB transport (only for Sessions ATM)
  * Add a way to cancel Session connection
  * FTP servers now expose a capability object
  * When creating new files, set permissions according to umask
  * Add a way to specify source Bluetooth adapter for Sessions
  * Let applications know about all sessions/servers running
  * Fix filename conversion to UTF-16 (bug introduced in 0.3.2)
  * Add manual page
  * Properly close sockets for Session and ServerSession objects
- Drop obex-server-bluez-libs-CVE-2008-2374.diff, its upstream
* Tue Sep 16 2008 ro@suse.de
- adapt CVE diff to bluez-4: function name back to original
  len paramer now also in sdp_extract_pdu
* Thu Jul  3 2008 tpatzig@suse.de
- update to v0.3.2
  * Reduce compiler warnings
  * Fix ServerSession Accept/Reject
  * Use different FTP UUID for some Nokia devices
  * Don't try to remove service record when it is not registered
  * Check OBEX Target header for FTP sessions
  * Disable FTP specific commands when OPP is used
  * Use UTF-8 filenames in folder listing objects
  * Improve OBEX error reporting
  * Fix crashers on exit
  * Portability fixes
  * Check connection ID for FTP session
  * Send empty Name header when using ChangeCurrentFolderToRoot
  * Don't try to access memory regions that were already freed
    Also fixes a long-standing segfault issue
* Wed Jul  2 2008 seife@suse.de
- added patch to adopt to API change in bluez libs caused by
  CVE-2008-2374 (bnc #404963)
* Tue May 27 2008 rodrigo@suse.de
- Added obex-data-server-unbreak-file-uris.patch to remove the
  file:// prefix from URIs, since those are not supported (bnc#391820)
* Thu Mar  6 2008 tpatzig@suse.de
- moved .service file to the right place (/usr/share/dbus-1/services)
- removed redundant dbus-1-devel buildrequires
* Thu Mar  6 2008 jpr@suse.de
- Fix dbus service file installation path
* Mon Mar  3 2008 tpatzig@suse.de
- update to v0.3
  * API change: Manager.CreateBluetoothServer(string source_address, string pattern, boolean require_pairing)
  * API change: Server.Start(string path, boolean allow_write, boolean auto_accept)
  * update ods-server-test.py according to new API
  * Remove some memory leaks
* Tue Feb 12 2008 tpatzig@suse.de
- update to v0.2
  * Distribute python tests (ods-session-test.py and ods-server-test.py).
  * Make object paths lowercase.
  * API change: Server.Start(string path, boolean allow_write, boolean require_pairing, boolean auto_accept).
  * New methods: Server.Accept(), Server.Reject().
  * Fix server SDP record lifetime (now exists between Start() and Stop()).
  * Make D-Bus system config file optional (enable with --enable-system-config configure option).
  * Exclude dot files from folder listings.
* Thu Feb  7 2008 tpatzig@suse.de
- initial package build
